@@ -5,10 +5,11 @@ use Moose::Util::TypeConstraints;
 
 use Template   ();
 use IO::String ();
+use Module::Runtime ();
 
 use Excel::Template;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.06';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'MooseX::Param';
@@ -42,7 +43,7 @@ has '_template_object' => (
     default => sub {
         my $self = shift;
         my $class = $self->template_class;
-        Class::MOP::load_class($class);
+        Module::Runtime::use_module($class);
         ($class->isa('Template'))
             || confess "The template_class must be Template or a subclass of it";
         $class->new( $self->config )
@@ -199,11 +200,11 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Infinity Interactive, Inc.
+Copyright 2007-2014 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
