@@ -9,7 +9,7 @@ use Test::Builder ();
 
 use Spreadsheet::ParseExcel;
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.06';
 our $AUTHORITY = 'cpan:STEVAN';
 
 require Exporter;
@@ -123,11 +123,11 @@ to cpan-RT.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+Copyright 2007-2014 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
